@@ -405,31 +405,31 @@ class TestGetData:
 
 class TestGetMetaData:
     @pytest.mark.destination
-    @pytest.mark.get_meta_data
+    @pytest.mark.get_metadata
     def test_returns_column_type_flg(self, get_good_meta_data):
         data = get_good_meta_data
         assert "column_type_flg" in data
 
     @pytest.mark.destination
-    @pytest.mark.get_meta_data
+    @pytest.mark.get_metadata
     def test_returns_size_flg(self, get_good_meta_data):
         data = get_good_meta_data
         assert "size_flg" in data
 
     @pytest.mark.destination
-    @pytest.mark.get_meta_data
+    @pytest.mark.get_metadata
     def test_returns_new_object_regex(self, get_good_meta_data):
         data = get_good_meta_data
         assert "new_object_regex" in data
 
     @pytest.mark.destination
-    @pytest.mark.get_meta_data
+    @pytest.mark.get_metadata
     def test_returns_size_regex(self, get_good_meta_data):
         data = get_good_meta_data
         assert "size_regex" in data
 
     @pytest.mark.destination
-    @pytest.mark.get_meta_data
+    @pytest.mark.get_metadata
     def test_returns_data_types(self, get_good_meta_data):
         data = get_good_meta_data
         assert "data_types" in data
